Class: Sol::LineChart
- Includes:
- CoordinateChart, Margins
- Defined in:
- lib/sol/line_chart.rb
Instance Attribute Summary
Attributes inherited from Chart
#dim, #jstype, #name, #properties, #spot, #type, #y_column
Instance Method Summary collapse
-
#render_area(bool = nil) ⇒ Object
———————————————————————————— Get or set render area flag.
-
#render_data_points(bool = nil) ⇒ Object
———————————————————————————— Get or set render area flag.
Methods included from Margins
Methods included from CoordinateChart
#brush_on, #clip_padding, #elastic_x, #elastic_y, #x, #x_axis_label, #y_axis_label
Methods inherited from Chart
build, #header, #initialize, #js_spec, #props
Methods included from BaseChart
#data, #dimension, #group, #grouped?, #height, #min_height, #min_width, #transition_duration, #width
Constructor Details
This class inherits a constructor from Sol::Chart
Instance Method Details
#render_area(bool = nil) ⇒ Object
Get or set render area flag. If the flag is set to true then the chart will render the area beneath each line and the line chart effectively becomes an area chart.
39 40 41 42 43 |
# File 'lib/sol/line_chart.rb', line 39 def render_area(bool = nil) return @properties["renderArea"] if bool == nil @properties["renderArea"] = bool return self end |
#render_data_points(bool = nil) ⇒ Object
Get or set render area flag. If the flag is set to true then the chart will render the area beneath each line and the line chart effectively becomes an area chart.
50 51 52 53 54 |
# File 'lib/sol/line_chart.rb', line 50 def render_data_points(bool = nil) return @properties["renderDataPoints"] if bool == nil @properties["renderDataPoints"] = bool return self end |